/**
 * Summary. (use period)
 *
 * Description. (use period)
 *
 * @link   URL
 * @file   This files defines mainly submit functions of buttons in variable.html
 * @author Vincent DELLA LIBERA
 * @since  x.x.x
 */


// Available web services for variables
const CREATE = 'create';
const GET = 'get';
const SET = 'set';
const DELETE = 'delete';

/**
 * Manage variable creation with the servlet.
 * @returns
 */
function create() {
	// Get values
	var name = $("#for-create-name").val();
	var value = $("#for-create-value").val();
	var type = $("#for-create-type").val();
	var isUserVar = $("#for-create-uservar").is(":checked");
	var userId = '';
	
	// Checks on them
	if(!name.trim()) {
		alert("Veuillez saisir un nom.");
		return;
	}
	
	if(!value.trim()) {
		alert("Veuillez saisir une valeur.");
		return;
	}
	
	if(!type.trim()) {
		alert("Veuillez saisir un type.");
		return;
	}
	
	if(isUserVar) {
		userId = $("#for-create-userid").val();
		
		if(!userId.trim()) {
			alert("Veuillez saisir un ID utilisateur ou décocher la case 'ID utilisateur' pour créer une variable globale.");
			return;
		}
	} else {
		userId = "0";
	}

	// Send values to servlet
	callServlet(
		"VariableServlet",
		{
			'varService': CREATE,
			'varName': name,
			'varValue': value,
			'varType': type,
			'varUserId': userId
		},
		function(data) {
			var val = $('#for-create-results').html();
			if(val.trim()) {
				val += '\n';
			}
			
			if(data.trim()) {
				$('#for-create-results').html(val + data);
			} else {
				$('#for-create-results').html(val + "Variable déjà existante...");
			}
		},
		function(error) {
			alert('Servlet was not called ...');
		}
	);
}

/**
 * Manage variable getting with the servlet.
 * @returns
 */
function get() {
	// Needed values
	var id = '';
	var name = '';
	var userId = '';
	
	// Checks whether service is from ID
	if($("#get-from-id").is(":checked")) {
		// Get value
		id = $("#for-get-id").val();
		
		// Check on it
		if(!id.trim()) {
			alert("Veuillez saisir un ID.");
			return;
		}
	// Checks whether service is from name
	} else if($("#get-from-name").is(":checked")) {
		// Get values
		name = $("#for-get-name").val();
		var isUserVar = $("#for-get-uservar").is(":checked");
		
		// Checks on them
		if(!name.trim()) {
			alert("Veuillez saisir un nom.");
			return;
		}
		
		if(isUserVar) {
			userId = $("#for-get-userid").val();
			
			if(!userId.trim()) {
				alert("Veuillez saisir un ID utilisateur ou décocher la case 'ID utilisateur' pour récupérer une variable globale.");
				return;
			}
		}		
	} else {
		alert("Veuillez sélectionner la récupération par ID ou par nom.");
		return;
	}

	// Send values to servlet
	callServlet(
		"VariableServlet",
		{
			'varService': GET,
			'varId': id,
			'varName': name,
			'varUserId': userId
		},
		function(data) {				
			if(data.trim()) {
				$('#for-get-results').html(data);
			} else {
				$('#for-get-results').html("Variable inexistante...");
			}
		},
		function(error) {
			alert('Servlet was not called ...');
		}
	);
}

/**
 * Manage variable setting with the servlet.
 * @returns
 */
function set() {
	// Needed values
	var id = '';
	var name = '';
	var value = '';
	var type = '';
	var userId = '';
	
	// Checks whether service is from ID
	if($("#set-from-id").is(":checked")) {
		// Get values
		id = $("#for-set-id").val();
		name = $("#for-set-name").val();
		value = $("#for-set-value").val();
		type = $("#for-set-type").val();
		userId = $("#for-set-userid").val();
		
		// Check on it
		if(!id.trim()) {
			alert("Veuillez saisir un ID.");
			return;
		}
		
		if(!name.trim() && !value.trim() && !type.trim() && !userId.trim()) {
			alert("Veuillez saisir au moins un champ à modifier.");
		}
	// Checks whether service is from name
	} else if($("#set-from-name").is(":checked")) {
		// Get values
		name = $("#for-set-name-from-name").val();
		var isUserVar = $("#for-set-uservar").is(":checked");
		value = $("#for-set-value").val();
		type = $("#for-set-type").val();
		
		// Checks on them
		if(!name.trim()) {
			alert("Veuillez saisir un nom.");
			return;
		}
		
		if(isUserVar) {
			userId = $("#for-set-userid-from-name").val();
			
			if(!userId.trim()) {
				alert("Veuillez saisir un ID utilisateur ou décocher la case 'ID utilisateur' pour modifier une variable globale.");
				return;
			}
		}
		
		if(!value.trim() && !type.trim()) {
			alert("Veuillez saisir au moins un champ à modifier.");
		}
	} else {
		alert("Veuillez sélectionner la modification par ID ou par nom.");
		return;
	}
	
	// Empty whitespace-only fields
	name = name.trim() ? name : name.trim();
	value = value.trim() ? value : value.trim();
	type = type.trim() ? type : type.trim();
	userId = userId.trim() ? userId : userId.trim();

	// Send values to servlet
	callServlet(
		"VariableServlet",
		{
			'varService': SET,
			'varId': id,
			'varName': name,
			'varValue': value,
			'varType': type,
			'varUserId': userId
		},
		function(data) {				
			if(data == "UPDATED") {
				$('#for-set-results').html("Variable modifiée !");
				$('#for-set-results').css("color", "Green");
			} else if(data.trim()) {
				$('#for-set-results').html(data);
				$('#for-set-results').css("color", "Orange");
			} else {
				$('#for-set-results').html("Variable inexistante...");
				$('#for-set-results').css("color", "Red");
			}
		},
		function(error) {
			alert('Servlet was not called ...');
		}
	);
}

function remove() {
	// Needed values
	var id = '';
	var name = '';
	var userId = '';
	
	// Checks whether service is from ID
	if($("#delete-from-id").is(":checked")) {
		// Get value
		id = $("#for-delete-id").val();
		
		// Check on it
		if(!id.trim()) {
			alert("Veuillez saisir un ID.");
			return;
		}
	// Checks whether service is from name
	} else if($("#delete-from-name").is(":checked")) {
		// Get values
		name = $("#for-delete-name").val();
		var isUserVar = $("#for-delete-uservar").is(":checked");
		
		// Checks on them
		if(!name.trim()) {
			alert("Veuillez saisir un nom.");
			return;
		}
		
		if(isUserVar) {
			userId = $("#for-delete-userid").val();
			
			if(!userId.trim()) {
				alert("Veuillez saisir un ID utilisateur ou décocher la case 'ID utilisateur' pour supprimer une variable globale.");
				return;
			}
		}		
	} else {
		alert("Veuillez sélectionner la suppression par ID ou par nom.");
		return;
	}

	// Send values to servlet
	callServlet(
		"VariableServlet",
		{
			'varService': DELETE,
			'varId': id,
			'varName': name,
			'varUserId': userId
		},
		function(data) {				
			if(data == "SUCCESS") {
				$('#for-delete-results').html("Variable supprimée !");
				$('#for-delete-results').css("color", "Green");
			} else if(data.trim()) {
				$('#for-delete-results').html(data);
				$('#for-delete-results').css("color", "Orange");
			} else {
				$('#for-delete-results').html("Variable inexistante...");
				$('#for-delete-results').css("color", "Red");
			}
		},
		function(error) {
			alert('Servlet was not called ...');
		}
	);
}

/******************************************/
/* When page has loaded, fix some details */
/******************************************/

$(function() {
	/** Creation section **/
	// Checkbox for enabling user ID field
	$("#for-create-uservar").change(function (){
		if(this.checked) {
			$("#for-create-userid").prop("disabled", false);
		} else {
			$("#for-create-userid").prop("disabled", true);
		}
	});
	
	/** Get section **/
	// Radio button for GetFromID fields
	$("#get-from-id").change(function() {
		if(this.checked) {
			// ID field elements
			$(".get-fields-id label").css("color", "Black");
			$(".get-fields-id input").prop("disabled", false);
			
			// Name field elements
			$(".get-fields-name label").css("color", "LightGray");
			$(".get-fields-name input").prop("disabled", true);
		}
	});
	
	// Radio button for GetFromName fields
	$("#get-from-name").change(function() {
		if(this.checked) {
			// ID field elements
			$(".get-fields-id label").css("color", "LightGray");
			$(".get-fields-id input").prop("disabled", true);
			
			// Name field elements
			$(".get-fields-name label").css("color", "Black");
			$(".get-fields-name input").prop("disabled", false);
			if($("#for-get-uservar").is(":checked")) {
				$("#for-get-userid").prop("disabled", false);
			} else {
				$("#for-get-userid").prop("disabled", true);
			}
		}
	});

	// Checkbox for enabling user ID field
	$("#for-get-uservar").change(function (){
		if(this.checked) {
			$("#for-get-userid").prop("disabled", false);
		} else {
			$("#for-get-userid").prop("disabled", true);
		}
	});
	
	/** Modification section **/
	// Radio button for SetFromID fields
	$("#set-from-id").change(function() {
		if(this.checked) {
			// ID field elements
			$(".set-fields-id label").css("color", "Black");
			$(".set-fields-id input").prop("disabled", false);
			
			// Name field elements
			$(".set-fields-name label").css("color", "LightGray");
			$(".set-fields-name input").prop("disabled", true);
			
			// Edition field elements
			$('#for-set-name').prop("disabled", false);
			$('#for-set-userid').prop("disabled", false);
		}
	});
	
	// Radio button for SetFromName fields
	$("#set-from-name").change(function() {
		if(this.checked) {
			// ID field elements
			$(".set-fields-id label").css("color", "LightGray");
			$(".set-fields-id input").prop("disabled", true);
			
			// Name field elements
			$(".set-fields-name label").css("color", "Black");
			$(".set-fields-name input").prop("disabled", false);
			if($("#for-set-uservar").is(":checked")) {
				$("#for-set-userid-from-name").prop("disabled", false);
			} else {
				$("#for-set-userid-from-name").prop("disabled", true);
			}
			
			// Edition field elements
			$('#for-set-name').prop("disabled", true);
			$('#for-set-userid').prop("disabled", true);
		}
	});

	// Checkbox for enabling user ID field
	$("#for-set-uservar").change(function (){
		if(this.checked) {
			$("#for-set-userid-from-name").prop("disabled", false);
		} else {
			$("#for-set-userid-from-name").prop("disabled", true);
		}
	});
	
	/** Deletion section **/
	// Radio button for DeleteFromID fields
	$("#delete-from-id").change(function() {
		if(this.checked) {
			// ID field elements
			$(".delete-fields-id label").css("color", "Black");
			$(".delete-fields-id input").prop("disabled", false);
			
			// Name field elements
			$(".delete-fields-name label").css("color", "LightGray");
			$(".delete-fields-name input").prop("disabled", true);
		}
	});
	
	// Radio button for DeleteFromName fields
	$("#delete-from-name").change(function() {
		if(this.checked) {
			// ID field elements
			$(".delete-fields-id label").css("color", "LightGray");
			$(".delete-fields-id input").prop("disabled", true);
			
			// Name field elements
			$(".delete-fields-name label").css("color", "Black");
			$(".delete-fields-name input").prop("disabled", false);
			if($("#for-delete-uservar").is(":checked")) {
				$("#for-delete-userid").prop("disabled", false);
			} else {
				$("#for-delete-userid").prop("disabled", true);
			}
		}
	});

	// Checkbox for enabling user ID field
	$("#for-delete-uservar").change(function (){
		if(this.checked) {
			$("#for-delete-userid").prop("disabled", false);
		} else {
			$("#for-delete-userid").prop("disabled", true);
		}
	});
});