package com.yellowbox.plugin.servlet;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;
import java.awt.image.AffineTransformOp;
import java.awt.image.BufferedImage;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.Base64;

import javax.imageio.ImageIO;

import org.json.JSONObject;

import com.yellowbox.plugin.v3.ParamValues;
import com.yellowbox.plugin.v3.Servlet;

public class ServletFichier extends Servlet {

	@Override
	public String call(ParamValues params) {
		byte[] toBW = params.getFileValue("image-bw");
		byte[] toRotate = params.getFileValue("image-rotate");
		String extensionBw = params.getStringValue("type-bw");
		String extensionRotate = params.getStringValue("type-rotate");
		extensionBw = extensionBw.substring(extensionBw.indexOf('/') +1, extensionBw.length());
		extensionRotate = extensionRotate.substring(extensionRotate.indexOf('/') +1, extensionRotate.length());

		ByteArrayInputStream baisBw = new ByteArrayInputStream(toBW);
		ByteArrayInputStream baisRotate = new ByteArrayInputStream(toRotate);
		BufferedImage imageBw = null;
		BufferedImage imageRotate = null;
		try {
			imageBw = ImageIO.read(baisBw);
			imageRotate = ImageIO.read(baisRotate);
		}catch(Exception e) {
			// gestion de l'exception
		}

		BufferedImage bw = bwImage(imageBw);
		BufferedImage rotated = rotateImage(imageRotate);
		ByteArrayOutputStream outBw = new ByteArrayOutputStream();
		ByteArrayOutputStream outRotate = new ByteArrayOutputStream();
		try {
			ImageIO.write(bw, extensionBw, outBw);
			ImageIO.write(rotated, extensionRotate, outRotate);
		} catch (IOException e) {
			// gestion de l'exception
		}
		JSONObject json = new JSONObject();
		json.put("imgbw", Base64.getEncoder().encodeToString(outBw.toByteArray()));
		json.put("imgrotate", Base64.getEncoder().encodeToString(outRotate.toByteArray()));
		return json.toString();
	}
    
    private BufferedImage bwImage(BufferedImage image) {
    	BufferedImage result = new BufferedImage(image.getWidth(), image.getHeight(), BufferedImage.TYPE_BYTE_BINARY);
        Graphics2D graphics = result.createGraphics();
        graphics.drawImage(image, 0,0,Color.WHITE,null);
        graphics.dispose();
        return result;
    }
    
    private BufferedImage rotateImage(BufferedImage image) {
    	double rads = Math.toRadians(90);
    	double sin = Math.abs(Math.sin(rads));
    	double cos = Math.abs(Math.cos(rads));
    	int width = (int) Math.floor(image.getWidth() * cos + image.getHeight() * sin);
    	int height = (int) Math.floor(image.getHeight() * cos + image.getWidth() * sin);
    	BufferedImage rotateImage = new BufferedImage(width, height, image.getType());
    	AffineTransform affineTransform = new AffineTransform();
    	affineTransform.translate(width / 2, height / 2);
    	affineTransform.rotate(rads,0,0);
    	affineTransform.translate(-image.getWidth() / 2, -image.getHeight() / 2);
    	AffineTransformOp affineTransformOp = new AffineTransformOp(affineTransform, AffineTransformOp.TYPE_BILINEAR);
    	affineTransformOp.filter(image,rotateImage);
    	return rotateImage;
    }

    @Override
    public String getName() {
        return "ServletFichier";
    }
    
}