package com.yellowbox.plugin.variable;

import org.apache.commons.lang3.StringUtils;

import com.yellowbox.plugin.exception.YbBadRequestException;
import com.yellowbox.plugin.service.IVariableService;
import com.yellowbox.plugin.v3.ParamValues;
import com.yellowbox.plugin.v3.Servlet;
import com.yellowbox.ws.beans.Variable;

public class VariableServlet extends Servlet {
	
	public final static String CREATE = "create";
	public final static String GET = "get";
	public final static String SET = "set";
	public final static String DELETE = "delete";	

	public final static String SERVICE = "varService";
	public final static	String ID = "varId";
	public final static String NAME = "varName";
	public final static String VALUE = "varValue";
	public final static String TYPE = "varType";
	public final static String USERID = "varUserId";	

	@Override
	public String call(ParamValues paramsServlet) {
		// Get which function is service is demanded
		String function = paramsServlet.getStringValue(SERVICE);
		IVariableService varService = ((VariableUI) getComponent())
				.getYellowboxEntryPoint()
				.getServices()
				.getVariableService();

		if(function.equals(CREATE)) {
			return create(paramsServlet, varService);
		} else if(function.equals(GET)) {
			return get(paramsServlet, varService);
		}else if(function.equals(SET)) {
			return set(paramsServlet, varService);
		} else if(function.equals(DELETE)) {
			return delete(paramsServlet, varService);
		} else {
			return "ERROR: function not recognized (" + function + ")";
		}
	}

	@Override
	public String getName() {
		return "VariableServlet";
	}
	
	private String create(ParamValues params, IVariableService service) {
		// Prepare values
		String name = params.getStringValue(NAME);
		String value = params.getStringValue(VALUE);
		String type = params.getStringValue(TYPE);
		String userId = params.getStringValue(USERID);		
		String varId = "";

		// Checks if variable was already created
		if(service.userVariableExists(name, userId)) {
			return "";
		}
		
		// Create a new variable support
		Variable var = new Variable();
		var.setName(name);
		var.setValue(value);
		var.setType(type);
		var.setUserId(userId);
		
		// Send variable support to service in order to create the variable
		try {
			varId = service.putVariable(var);
		} catch(YbBadRequestException e) {
			if(e.getMessage().contains("user")) {
				return "ID utilisateur incorrect";
			} else {
				return e.getMessage();
			}
		}
		
		return varId;
	}

	private String get(ParamValues params, IVariableService service) {
		// Prepare values
		String id = params.getStringValue(ID);
		String name = params.getStringValue(NAME);
		String userId = params.getStringValue(USERID);
		Variable var;
		
		// Checks from which value the variable will be got
		if(StringUtils.isNotBlank(id)) {
			try {
				var = service.getVariable(id);
			} catch(Exception e) {
				return e.getMessage();
			}
		} else if(StringUtils.isNotBlank(name)) {
			try {
				var = service.getUserVariable(name, userId);
			} catch(YbBadRequestException e) {
				if(e.getMessage().contains("user")) {
					return "ID utilisateur incorrect";
				} else {
					return e.getMessage();
				}
			}
		} else {
			return "Un des champs n'est pas rempli ...";
		}

		// Checks if a variable was found
		if(var == null) {
			return "";
		} else {
			return "ID : " + var.getId() + "\n"
					+ "Nom : " + var.getName() + "\n"
					+ "Valeur : " + var.getValue() + "\n"
					+ "Type : " + var.getType() + "\n"
					+ "ID Utilisateur : " + var.getUserId() + "\n"
					+ "Date creation : " + var.getCreationDate() + "\n"
					+ "Dernier acces : " + var.getLastAccessDate();
		}
	}

	private String set(ParamValues params, IVariableService service) {
		// Prepare values 
		String id = params.getStringValue(ID);
		String name = params.getStringValue(NAME);
		String value = params.getStringValue(VALUE);
		String type = params.getStringValue(TYPE);
		String userId = params.getStringValue(USERID);
		Variable var;
		String response = "";
		
		// Checks from which values the variable will be edited
		if(StringUtils.isNotBlank(id)) {
			if(!service.variableExists(id)) {
				return "";
			}
		} else if(StringUtils.isNotBlank(name)) {
			if(!service.userVariableExists(name, userId)) {
				return "";
			}
		} else {
			return "";
		}
		
		// Create a new variable support to edit new values
		var = new Variable();
		var.setId(id);
		var.setName(name);
		var.setValue(value);
		var.setType(type);
		var.setUserId(userId);

		// Send variable support to service in order to edit the variable
		try {
			response = service.putVariable(var);
		} catch(YbBadRequestException e) {
			if(e.getMessage().contains("user")) {
				return "ID utilisateur incorrect";
			} else {
				return e.getMessage();
			}
		}
		
		return response;
	}
	
	private String delete(ParamValues params, IVariableService service) {
		// Prepare values
		String id = params.getStringValue(ID);
		String name = params.getStringValue(NAME);
		String userId = params.getStringValue(USERID);
		String response = "";
		
		// Checks from which value the variable will be deleted
		if(StringUtils.isNotBlank(id)) {
			if(service.variableExists(id)) {
				try {
					response = service.deleteVariable(id);
				} catch(YbBadRequestException e) {
					if(e.getMessage().contains("user")) {
						return "ID utilisateur incorrect";
					} else {
						return e.getMessage();
					}
				}
			} else {
				return "";
			}
		} else if(StringUtils.isNotBlank(name)) {
			if(service.userVariableExists(name, userId)) {
				try {
					if(StringUtils.isNotBlank(userId)) {
						response = service.deleteUserVariable(name, userId);
					} else {
						response = service.deleteAllVariableWithSameName(name);
					}
				} catch(YbBadRequestException e) {
					if(e.getMessage().contains("user")) {
						return "ID utilisateur incorrect";
					} else {
						return e.getMessage();
					}
				}
			} else {
				return "";
			}
		} else {
			return "Un des champs n'est pas rempli ...";
		}

		return response;
	}
	
}
