package com.yellowbox.plugin.yblist.servlets;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.yellowbox.plugin.v3.ybobjects.yblist.ybcell.YbCell;
import com.yellowbox.plugin.v3.ybobjects.yblist.ybserverdata.YbListServerData;
import com.yellowbox.plugin.v3.ybobjects.yblist.ybserverdata.servlets.YbListUpdateServlet;
import com.yellowbox.plugin.v3.ybobjects.yblist.ybserverdata.servlets.params.YbListUpdateServletParams;
import com.yellowbox.plugin.yblist.components.YbListComponent;
import com.yellowbox.plugin.yblist.utils.YbListUtils;
import com.yellowbox.ws.beans.Page;
import com.yellowbox.ws.beans.Record;
import com.yellowbox.ws.beans.Value;

public class YbListServerServlet extends YbListUpdateServlet {

    @Override
    public YbListServerData update(YbListUpdateServletParams params) {        
        YbListUtils utils = new YbListUtils(getYellowboxEntryPoint());
        String searchId = getComponent().getParamValues().getStringValue(YbListComponent.IDRECHERCHE);
        Page<Record> recordPage = utils.getRecordsFromSearch(searchId);

		int start = params.getStart();
		int length = params.getLength();
        String search = params.getSearch().getValue();

        List<Record> records = recordPage.getContent().stream()
            .filter(r -> r.getValues().stream()
                .filter(v -> v.getField().getId().equals(YbListUtils.ID_FIELD_RS))
                .findAny()
                .orElse(new Value())
            .getValue().toLowerCase().contains(search.toLowerCase()))
            .collect(Collectors.toList());

        List<Record> subList = records.subList(start, (start + length > records.size() ? ((int) records.size()) : start + length));
        List<Map<String, YbCell>> data = utils.buildData(subList);
        
		int draw = params.getDraw();
        return new YbListServerData(data, draw, recordPage.getContent().size(), records.size());
    }

    @Override
    public String getName() {
        return getClass().getSimpleName();
    }
}
