package com.yellowbox.plugin.yblist.utils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.yellowbox.plugin.v3.YellowboxEntryPoint;
import com.yellowbox.plugin.v3.ybobjects.yblist.ybcell.YbButtonCell;
import com.yellowbox.plugin.v3.ybobjects.yblist.ybcell.YbCell;
import com.yellowbox.plugin.v3.ybobjects.yblist.ybcell.YbLinkCell;
import com.yellowbox.plugin.v3.ybobjects.yblist.ybcell.YbRawCell;
import com.yellowbox.plugin.v3.ybobjects.yblist.ybcolumn.YbColumn;
import com.yellowbox.plugin.v3.ybobjects.yblist.ybcolumn.YbColumn.Type;
import com.yellowbox.ws.beans.Field;
import com.yellowbox.ws.beans.Page;
import com.yellowbox.ws.beans.QueryPage;
import com.yellowbox.ws.beans.Record;
import com.yellowbox.ws.beans.Value;

public class YbListUtils {

    public static final String ID_FIELD_RS = "107";
    public static final String ID_FIELD_ACT = "261";
    private YellowboxEntryPoint entryPoint;

    public YbListUtils(YellowboxEntryPoint entryPoint) {
        this.entryPoint = entryPoint;
    }

    public List<YbColumn> buildColumns() {
        List<YbColumn> columns = new ArrayList<>();
        columns.add(new YbColumn("0", Type.BUTTON, "Lien"));

        Field field;
        String id;
        Type type;
        for(String idChamp : Arrays.asList(ID_FIELD_RS, ID_FIELD_ACT)) {
        	field = entryPoint.getServices().getFieldService().getFieldById(idChamp);

            id = ID_FIELD_RS.equals(idChamp) ? "raison_sociale" : "activite";
            type = field.getId().equals(ID_FIELD_RS) ? Type.LINK : Type.RAW;

            columns.add(new YbColumn(id, type, field.getName()));
        }

        return columns;
    }

    public List<Map<String, YbCell>> buildData(List<Record> records) {
        List<Map<String, YbCell>> data = new ArrayList<>();
        Map<String, YbCell> row;
        YbCell cell;

        for (Record societe : records) {
        	row = new HashMap<>();

            cell = new YbButtonCell("() => { window.open('https://www.google.com', '_blank').focus(); }", "https://upload.wikimedia.org/wikipedia/commons/6/6d/Windows_Settings_app_icon.png");
            row.put("0", cell);

            for(Value val: societe.getValues()) {
                if(!val.getField().getId().equals(ID_FIELD_ACT) && !val.getField().getId().equals(ID_FIELD_RS)) {
                    continue;
                }
                
                if(val.getField().getId().equals(ID_FIELD_ACT)) {
                    cell = new YbRawCell(val.getValue());
                    row.put("activite", cell);
                } else if(val.getField().getId().equals(ID_FIELD_RS)) {
                    cell = new YbLinkCell(val.getValue(), "() => { callServlet('YbListCellServlet', { 'param1': 'val1', 'param2': 'val2' }, (res) => { alert(res); }, (err) => { console.error(err); }); }");
                    row.put("raison_sociale", cell);
                }
            }
            	
            data.add(row);
        }

        return data;
    }
    
    public Page<Record> getRecordsFromSearch(String searchId) {
        List<Field> fields = new ArrayList<>();
        fields.add(new Field(ID_FIELD_RS, "", ""));
        fields.add(new Field(ID_FIELD_ACT, "", ""));

        QueryPage query = new QueryPage();
        query.setIdSearch(searchId);
        query.setFields(fields);

        return entryPoint.getServices().getRecordServiceV3().getRecordsBySearch(query);
    }

}
